diff --git a/core/modules/edit/edit.services.yml b/core/modules/edit/edit.services.yml
deleted file mode 100644
index eb8677e..0000000
--- a/core/modules/edit/edit.services.yml
+++ /dev/null
@@ -1,18 +0,0 @@
-services:
-  plugin.manager.edit.editor:
-    class: Drupal\edit\Plugin\InPlaceEditorManager
-    arguments: ['@container.namespaces']
-  access_check.edit.entity_field:
-    class: Drupal\edit\Access\EditEntityFieldAccessCheck
-    tags:
-      - { name: access_check }
-  access_check.edit.entity:
-    class: Drupal\edit\Access\EditEntityAccessCheck
-    tags:
-      - { name: access_check }
-  edit.editor.selector:
-    class: Drupal\edit\EditorSelector
-    arguments: ['@plugin.manager.edit.editor']
-  edit.metadata.generator:
-    class: Drupal\edit\MetadataGenerator
-    arguments: ['@access_check.edit.entity_field', '@edit.editor.selector', '@plugin.manager.edit.editor']
diff --git a/core/modules/editor/editor.module b/core/modules/editor/editor.module
index af2b8ea..523110a 100644
--- a/core/modules/editor/editor.module
+++ b/core/modules/editor/editor.module
@@ -126,7 +126,7 @@ function editor_library_info() {
       ),
     ),
     'dependencies' => array(
-      array('edit', 'edit'),
+      array('quickedit', 'edit'),
       array('editor', 'drupal.editor'),
       array('system', 'drupal.ajax'),
       array('system', 'drupalSettings'),
diff --git a/core/modules/editor/lib/Drupal/editor/Ajax/GetUntransformedTextCommand.php b/core/modules/editor/lib/Drupal/editor/Ajax/GetUntransformedTextCommand.php
index c1971d1..99f8d4e 100644
--- a/core/modules/editor/lib/Drupal/editor/Ajax/GetUntransformedTextCommand.php
+++ b/core/modules/editor/lib/Drupal/editor/Ajax/GetUntransformedTextCommand.php
@@ -8,7 +8,7 @@
 namespace Drupal\editor\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
-use Drupal\edit\Ajax\BaseCommand;
+use Drupal\quickedit\Ajax\BaseCommand;
 
 /**
  * AJAX command to rerender a processed text field without any transformation
diff --git a/core/modules/editor/lib/Drupal/editor/Plugin/InPlaceEditor/Editor.php b/core/modules/editor/lib/Drupal/editor/Plugin/InPlaceEditor/Editor.php
index 1a4981a..dafc177 100644
--- a/core/modules/editor/lib/Drupal/editor/Plugin/InPlaceEditor/Editor.php
+++ b/core/modules/editor/lib/Drupal/editor/Plugin/InPlaceEditor/Editor.php
@@ -8,9 +8,9 @@
 namespace Drupal\editor\Plugin\InPlaceEditor;
 
 use Drupal\Component\Plugin\PluginBase;
-use Drupal\edit\Annotation\InPlaceEditor;
+use Drupal\quickedit\Annotation\InPlaceEditor;
 use Drupal\Core\Annotation\Translation;
-use Drupal\edit\EditPluginInterface;
+use Drupal\quickedit\EditPluginInterface;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
 /**
@@ -65,7 +65,7 @@ protected function textFormatHasTransformationFilters($format_id) {
   }
 
   /**
-   * Implements \Drupal\edit\EditPluginInterface::getAttachments().
+   * Implements \Drupal\quickedit\EditPluginInterface::getAttachments().
    */
   public function getAttachments() {
     global $user;
diff --git a/core/modules/editor/lib/Drupal/editor/Tests/EditIntegrationTest.php b/core/modules/editor/lib/Drupal/editor/Tests/EditIntegrationTest.php
index d2ec5e6..f2f9350 100644
--- a/core/modules/editor/lib/Drupal/editor/Tests/EditIntegrationTest.php
+++ b/core/modules/editor/lib/Drupal/editor/Tests/EditIntegrationTest.php
@@ -8,10 +8,10 @@
 namespace Drupal\editor\Tests;
 
 use Drupal\Core\Language\Language;
-use Drupal\edit\EditorSelector;
-use Drupal\edit\MetadataGenerator;
-use Drupal\edit\Plugin\InPlaceEditorManager;
-use Drupal\edit\Tests\EditTestBase;
+use Drupal\quickedit\EditorSelector;
+use Drupal\quickedit\MetadataGenerator;
+use Drupal\quickedit\Plugin\InPlaceEditorManager;
+use Drupal\quickedit\Tests\EditTestBase;
 use Drupal\edit_test\MockEditEntityFieldAccessCheck;
 use Drupal\editor\EditorController;
 use Symfony\Component\HttpFoundation\Request;
@@ -31,21 +31,21 @@ class EditIntegrationTest extends EditTestBase {
   /**
    * The metadata generator object to be tested.
    *
-   * @var \Drupal\edit\MetadataGeneratorInterface.php
+   * @var \Drupal\quickedit\MetadataGeneratorInterface.php
    */
   protected $metadataGenerator;
 
   /**
    * The editor selector object to be used by the metadata generator object.
    *
-   * @var \Drupal\edit\EditorSelectorInterface
+   * @var \Drupal\quickedit\EditorSelectorInterface
    */
   protected $editorSelector;
 
   /**
    * The access checker object to be used by the metadata generator object.
    *
-   * @var \Drupal\edit\Access\EditEntityFieldAccessCheckInterface
+   * @var \Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface
    */
   protected $accessChecker;
 
diff --git a/core/modules/edit/css/edit.icons.css b/core/modules/quickedit/css/edit.icons.css
similarity index 100%
rename from core/modules/edit/css/edit.icons.css
rename to core/modules/quickedit/css/edit.icons.css
diff --git a/core/modules/edit/css/edit.module.css b/core/modules/quickedit/css/edit.module.css
similarity index 100%
rename from core/modules/edit/css/edit.module.css
rename to core/modules/quickedit/css/edit.module.css
diff --git a/core/modules/edit/css/edit.theme.css b/core/modules/quickedit/css/edit.theme.css
similarity index 100%
rename from core/modules/edit/css/edit.theme.css
rename to core/modules/quickedit/css/edit.theme.css
diff --git a/core/modules/edit/images/attention.png b/core/modules/quickedit/images/attention.png
similarity index 100%
rename from core/modules/edit/images/attention.png
rename to core/modules/quickedit/images/attention.png
diff --git a/core/modules/edit/images/icon-close.png b/core/modules/quickedit/images/icon-close.png
similarity index 100%
rename from core/modules/edit/images/icon-close.png
rename to core/modules/quickedit/images/icon-close.png
diff --git a/core/modules/edit/images/icon-throbber.gif b/core/modules/quickedit/images/icon-throbber.gif
similarity index 100%
rename from core/modules/edit/images/icon-throbber.gif
rename to core/modules/quickedit/images/icon-throbber.gif
diff --git a/core/modules/edit/js/edit.js b/core/modules/quickedit/js/edit.js
similarity index 100%
rename from core/modules/edit/js/edit.js
rename to core/modules/quickedit/js/edit.js
diff --git a/core/modules/edit/js/editors/directEditor.js b/core/modules/quickedit/js/editors/directEditor.js
similarity index 100%
rename from core/modules/edit/js/editors/directEditor.js
rename to core/modules/quickedit/js/editors/directEditor.js
diff --git a/core/modules/edit/js/editors/formEditor.js b/core/modules/quickedit/js/editors/formEditor.js
similarity index 100%
rename from core/modules/edit/js/editors/formEditor.js
rename to core/modules/quickedit/js/editors/formEditor.js
diff --git a/core/modules/edit/js/models/AppModel.js b/core/modules/quickedit/js/models/AppModel.js
similarity index 100%
rename from core/modules/edit/js/models/AppModel.js
rename to core/modules/quickedit/js/models/AppModel.js
diff --git a/core/modules/edit/js/models/EditorModel.js b/core/modules/quickedit/js/models/EditorModel.js
similarity index 100%
rename from core/modules/edit/js/models/EditorModel.js
rename to core/modules/quickedit/js/models/EditorModel.js
diff --git a/core/modules/edit/js/models/EntityModel.js b/core/modules/quickedit/js/models/EntityModel.js
similarity index 100%
rename from core/modules/edit/js/models/EntityModel.js
rename to core/modules/quickedit/js/models/EntityModel.js
diff --git a/core/modules/edit/js/models/FieldModel.js b/core/modules/quickedit/js/models/FieldModel.js
similarity index 100%
rename from core/modules/edit/js/models/FieldModel.js
rename to core/modules/quickedit/js/models/FieldModel.js
diff --git a/core/modules/edit/js/theme.js b/core/modules/quickedit/js/theme.js
similarity index 100%
rename from core/modules/edit/js/theme.js
rename to core/modules/quickedit/js/theme.js
diff --git a/core/modules/edit/js/util.js b/core/modules/quickedit/js/util.js
similarity index 100%
rename from core/modules/edit/js/util.js
rename to core/modules/quickedit/js/util.js
diff --git a/core/modules/edit/js/views/AppView.js b/core/modules/quickedit/js/views/AppView.js
similarity index 100%
rename from core/modules/edit/js/views/AppView.js
rename to core/modules/quickedit/js/views/AppView.js
diff --git a/core/modules/edit/js/views/ContextualLinkView.js b/core/modules/quickedit/js/views/ContextualLinkView.js
similarity index 100%
rename from core/modules/edit/js/views/ContextualLinkView.js
rename to core/modules/quickedit/js/views/ContextualLinkView.js
diff --git a/core/modules/edit/js/views/EditorDecorationView.js b/core/modules/quickedit/js/views/EditorDecorationView.js
similarity index 100%
rename from core/modules/edit/js/views/EditorDecorationView.js
rename to core/modules/quickedit/js/views/EditorDecorationView.js
diff --git a/core/modules/edit/js/views/EditorView.js b/core/modules/quickedit/js/views/EditorView.js
similarity index 100%
rename from core/modules/edit/js/views/EditorView.js
rename to core/modules/quickedit/js/views/EditorView.js
diff --git a/core/modules/edit/js/views/EntityToolbarView.js b/core/modules/quickedit/js/views/EntityToolbarView.js
similarity index 100%
rename from core/modules/edit/js/views/EntityToolbarView.js
rename to core/modules/quickedit/js/views/EntityToolbarView.js
diff --git a/core/modules/edit/js/views/EntityView.js b/core/modules/quickedit/js/views/EntityView.js
similarity index 100%
rename from core/modules/edit/js/views/EntityView.js
rename to core/modules/quickedit/js/views/EntityView.js
diff --git a/core/modules/edit/js/views/FieldToolbarView.js b/core/modules/quickedit/js/views/FieldToolbarView.js
similarity index 100%
rename from core/modules/edit/js/views/FieldToolbarView.js
rename to core/modules/quickedit/js/views/FieldToolbarView.js
diff --git a/core/modules/edit/js/views/ModalView.js b/core/modules/quickedit/js/views/ModalView.js
similarity index 100%
rename from core/modules/edit/js/views/ModalView.js
rename to core/modules/quickedit/js/views/ModalView.js
diff --git a/core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheck.php b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheck.php
similarity index 92%
rename from core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheck.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheck.php
index 495c234..6311a5d 100644
--- a/core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheck.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheck.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Access\EditEntityAccessCheck.
+ * Contains \Drupal\quickedit\Access\EditEntityAccessCheck.
  */
 
-namespace Drupal\edit\Access;
+namespace Drupal\quickedit\Access;
 
 use Drupal\Core\Access\StaticAccessCheckInterface;
 use Symfony\Component\Routing\Route;
@@ -22,7 +22,7 @@ class EditEntityAccessCheck implements StaticAccessCheckInterface, EditEntityAcc
    * {@inheritdoc}
    */
   public function appliesTo() {
-    // @see edit.routing.yml
+    // @see quickedit.routing.yml
     return array('_access_edit_entity');
   }
 
diff --git a/core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheckInterface.php b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheckInterface.php
similarity index 73%
rename from core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheckInterface.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheckInterface.php
index 5df39e1..5010810 100644
--- a/core/modules/edit/lib/Drupal/edit/Access/EditEntityAccessCheckInterface.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityAccessCheckInterface.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Access\EditEntityAccessCheckInterface.
+ * Contains \Drupal\quickedit\Access\EditEntityAccessCheckInterface.
  */
 
-namespace Drupal\edit\Access;
+namespace Drupal\quickedit\Access;
 
 use Drupal\Core\Entity\EntityInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheck.php b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheck.php
similarity index 95%
rename from core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheck.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheck.php
index 9ec569a..ba448b4 100644
--- a/core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheck.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheck.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Access\EditEntityFieldAccessCheck.
+ * Contains \Drupal\quickedit\Access\EditEntityFieldAccessCheck.
  */
 
-namespace Drupal\edit\Access;
+namespace Drupal\quickedit\Access;
 
 use Drupal\Core\Access\StaticAccessCheckInterface;
 use Symfony\Component\Routing\Route;
diff --git a/core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheckInterface.php b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheckInterface.php
similarity index 75%
rename from core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheckInterface.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheckInterface.php
index fe6d918..f89c126 100644
--- a/core/modules/edit/lib/Drupal/edit/Access/EditEntityFieldAccessCheckInterface.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Access/EditEntityFieldAccessCheckInterface.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Access\EditEntityFieldAccessCheckInterface.
+ * Contains \Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface.
  */
 
-namespace Drupal\edit\Access;
+namespace Drupal\quickedit\Access;
 
 use Drupal\Core\Entity\EntityInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Ajax/BaseCommand.php b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/BaseCommand.php
similarity index 82%
rename from core/modules/edit/lib/Drupal/edit/Ajax/BaseCommand.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Ajax/BaseCommand.php
index 3a07b7f..27a43ef 100644
--- a/core/modules/edit/lib/Drupal/edit/Ajax/BaseCommand.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/BaseCommand.php
@@ -2,15 +2,15 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Ajax\BaseCommand.
+ * Contains \Drupal\quickedit\Ajax\BaseCommand.
  */
 
-namespace Drupal\edit\Ajax;
+namespace Drupal\quickedit\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
 
 /**
- * Base AJAX command that only exists simplify Edit's actual AJAX commands.
+ * Base AJAX command that simplifies Quick Edit's actual AJAX commands.
  */
 class BaseCommand implements CommandInterface {
 
diff --git a/core/modules/edit/lib/Drupal/edit/Ajax/EntitySavedCommand.php b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/EntitySavedCommand.php
similarity index 83%
rename from core/modules/edit/lib/Drupal/edit/Ajax/EntitySavedCommand.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Ajax/EntitySavedCommand.php
index 6b6cc59..58b26d1 100644
--- a/core/modules/edit/lib/Drupal/edit/Ajax/EntitySavedCommand.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/EntitySavedCommand.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Ajax\EntitySavedCommand.
+ * Contains \Drupal\quickedit\Ajax\EntitySavedCommand.
  */
 
-namespace Drupal\edit\Ajax;
+namespace Drupal\quickedit\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormCommand.php b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormCommand.php
similarity index 68%
rename from core/modules/edit/lib/Drupal/edit/Ajax/FieldFormCommand.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormCommand.php
index 781e2ff..243baace 100644
--- a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormCommand.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormCommand.php
@@ -2,15 +2,15 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Ajax\FieldFormCommand.
+ * Contains \Drupal\quickedit\Ajax\FieldFormCommand.
  */
 
-namespace Drupal\edit\Ajax;
+namespace Drupal\quickedit\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
 
 /**
- * AJAX command for passing a rendered field form to Edit's JavaScript app.
+ * AJAX command for passing a rendered field form to Quick Edit's JS app.
  */
 class FieldFormCommand extends BaseCommand {
 
diff --git a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormSavedCommand.php b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormSavedCommand.php
similarity index 84%
rename from core/modules/edit/lib/Drupal/edit/Ajax/FieldFormSavedCommand.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormSavedCommand.php
index 2e89c19..da37552 100644
--- a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormSavedCommand.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormSavedCommand.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Ajax\FieldFormSavedCommand.
+ * Contains \Drupal\quickedit\Ajax\FieldFormSavedCommand.
  */
 
-namespace Drupal\edit\Ajax;
+namespace Drupal\quickedit\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormValidationErrorsCommand.php b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormValidationErrorsCommand.php
similarity index 83%
rename from core/modules/edit/lib/Drupal/edit/Ajax/FieldFormValidationErrorsCommand.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormValidationErrorsCommand.php
index a44be4b..025140d 100644
--- a/core/modules/edit/lib/Drupal/edit/Ajax/FieldFormValidationErrorsCommand.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Ajax/FieldFormValidationErrorsCommand.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Ajax\FieldFormValidationErrorsCommand.
+ * Contains \Drupal\quickedit\Ajax\FieldFormValidationErrorsCommand.
  */
 
-namespace Drupal\edit\Ajax;
+namespace Drupal\quickedit\Ajax;
 
 use Drupal\Core\Ajax\CommandInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Annotation/InPlaceEditor.php b/core/modules/quickedit/lib/Drupal/quickedit/Annotation/InPlaceEditor.php
similarity index 85%
rename from core/modules/edit/lib/Drupal/edit/Annotation/InPlaceEditor.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Annotation/InPlaceEditor.php
index 2f889c7..eb310ca 100644
--- a/core/modules/edit/lib/Drupal/edit/Annotation/InPlaceEditor.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Annotation/InPlaceEditor.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Annotation\InPlaceEditor.
+ * Contains \Drupal\quickedit\Annotation\InPlaceEditor.
  */
 
-namespace Drupal\edit\Annotation;
+namespace Drupal\quickedit\Annotation;
 
 use Drupal\Component\Annotation\Plugin;
 
diff --git a/core/modules/edit/lib/Drupal/edit/EditController.php b/core/modules/quickedit/lib/Drupal/quickedit/EditController.php
similarity index 88%
rename from core/modules/edit/lib/Drupal/edit/EditController.php
rename to core/modules/quickedit/lib/Drupal/quickedit/EditController.php
index 3cfa3d1..34f12f6 100644
--- a/core/modules/edit/lib/Drupal/edit/EditController.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/EditController.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains of \Drupal\edit\EditController.
+ * Contains \Drupal\quickedit\EditController.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal;
 use Symfony\Component\DependencyInjection\ContainerAware;
@@ -14,15 +14,15 @@
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Drupal\Core\Ajax\AjaxResponse;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\edit\Ajax\FieldFormCommand;
-use Drupal\edit\Ajax\FieldFormSavedCommand;
-use Drupal\edit\Ajax\FieldFormValidationErrorsCommand;
-use Drupal\edit\Ajax\EntitySavedCommand;
-use Drupal\edit\Ajax\MetadataCommand;
+use Drupal\quickedit\Ajax\FieldFormCommand;
+use Drupal\quickedit\Ajax\FieldFormSavedCommand;
+use Drupal\quickedit\Ajax\FieldFormValidationErrorsCommand;
+use Drupal\quickedit\Ajax\EntitySavedCommand;
+use Drupal\quickedit\Ajax\MetadataCommand;
 use Drupal\user\TempStoreFactory;
 
 /**
- * Returns responses for Edit module routes.
+ * Returns responses for Quick Edit module routes.
  */
 class EditController extends ContainerAware {
 
@@ -60,7 +60,7 @@ public function metadata(Request $request) {
     }
     $entities = $request->request->get('entities');
 
-    $metadataGenerator = $this->container->get('edit.metadata.generator');
+    $metadataGenerator = $this->container->get('quickedit.metadata.generator');
 
     $metadata = array();
     foreach ($fields as $field) {
@@ -111,7 +111,7 @@ public function attachments(Request $request) {
       throw new NotFoundHttpException();
     }
 
-    $editorSelector = $this->container->get('edit.editor.selector');
+    $editorSelector = $this->container->get('quickedit.editor.selector');
     $elements['#attached'] = $editorSelector->getEditorAttachments($editors);
     drupal_process_attached($elements);
 
@@ -140,12 +140,12 @@ public function fieldForm(EntityInterface $entity, $field_name, $langcode, $view
 
     // Replace entity with tempstore copy if available and not resetting, init
     // tempstore copy otherwise.
-    $tempstore_entity = $this->tempStoreFactory->get('edit')->get($entity->uuid());
+    $tempstore_entity = $this->tempStoreFactory->get('quickedit')->get($entity->uuid());
     if ($tempstore_entity && !(isset($_POST['reset']) && $_POST['reset'] === 'true')) {
       $entity = $tempstore_entity;
     }
     else {
-      $this->tempStoreFactory->get('edit')->set($entity->uuid(), $entity);
+      $this->tempStoreFactory->get('quickedit')->set($entity->uuid(), $entity);
     }
 
     $form_state = array(
@@ -158,7 +158,7 @@ public function fieldForm(EntityInterface $entity, $field_name, $langcode, $view
     if (!empty($form_state['executed'])) {
       // The form submission saved the entity in tempstore. Return the
       // updated view of the field from the tempstore copy.
-      $entity = $this->tempStoreFactory->get('edit')->get($entity->uuid());
+      $entity = $this->tempStoreFactory->get('quickedit')->get($entity->uuid());
       // @todo Remove when http://drupal.org/node/1346214 is complete.
       $entity = $entity->getBCEntity();
       $output = field_view_field($entity, $field_name, $view_mode_id, $langcode);
@@ -195,7 +195,7 @@ public function fieldForm(EntityInterface $entity, $field_name, $langcode, $view
   public function entitySave(EntityInterface $entity) {
     // Take the entity from tempstore and save in entity storage. fieldForm()
     // ensures that the tempstore copy exists ahead.
-    $tempstore = $this->tempStoreFactory->get('edit');
+    $tempstore = $this->tempStoreFactory->get('quickedit');
     $tempstore->get($entity->uuid())->save();
     $tempstore->delete($entity->uuid());
 
diff --git a/core/modules/edit/lib/Drupal/edit/EditorBase.php b/core/modules/quickedit/lib/Drupal/quickedit/EditorBase.php
similarity index 77%
rename from core/modules/edit/lib/Drupal/edit/EditorBase.php
rename to core/modules/quickedit/lib/Drupal/quickedit/EditorBase.php
index 10b2f02..a42e323 100644
--- a/core/modules/edit/lib/Drupal/edit/EditorBase.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/EditorBase.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\edit\EditorBase.
+ * Contains \Drupal\quickedit\EditorBase.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Component\Plugin\PluginBase;
-use Drupal\edit\EditPluginInterface;
+use Drupal\quickedit\EditPluginInterface;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
 /**
diff --git a/core/modules/edit/lib/Drupal/edit/EditorSelector.php b/core/modules/quickedit/lib/Drupal/quickedit/EditorSelector.php
similarity index 97%
rename from core/modules/edit/lib/Drupal/edit/EditorSelector.php
rename to core/modules/quickedit/lib/Drupal/quickedit/EditorSelector.php
index 2636f38..46cb492 100644
--- a/core/modules/edit/lib/Drupal/edit/EditorSelector.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/EditorSelector.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\EditorSelector.
+ * Contains \Drupal\quickedit\EditorSelector.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Component\Utility\NestedArray;
diff --git a/core/modules/edit/lib/Drupal/edit/EditorSelectorInterface.php b/core/modules/quickedit/lib/Drupal/quickedit/EditorSelectorInterface.php
similarity index 92%
rename from core/modules/edit/lib/Drupal/edit/EditorSelectorInterface.php
rename to core/modules/quickedit/lib/Drupal/quickedit/EditorSelectorInterface.php
index d36083a..d616995 100644
--- a/core/modules/edit/lib/Drupal/edit/EditorSelectorInterface.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/EditorSelectorInterface.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\EditorSelectorInterface.
+ * Contains \Drupal\quickedit\EditorSelectorInterface.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
diff --git a/core/modules/edit/lib/Drupal/edit/Form/EditFieldForm.php b/core/modules/quickedit/lib/Drupal/quickedit/Form/EditFieldForm.php
similarity index 96%
rename from core/modules/edit/lib/Drupal/edit/Form/EditFieldForm.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Form/EditFieldForm.php
index e14e0d2..01094bb 100644
--- a/core/modules/edit/lib/Drupal/edit/Form/EditFieldForm.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Form/EditFieldForm.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Form\EditFieldForm.
+ * Contains \Drupal\quickedit\Form\EditFieldForm.
  */
 
-namespace Drupal\edit\Form;
+namespace Drupal\quickedit\Form;
 
 use Drupal;
 use Drupal\Core\Entity\EntityInterface;
@@ -100,7 +100,7 @@ public function submit(array $form, array &$form_state) {
     $form_state['entity'] = $this->buildEntity($form, $form_state);
 
     // Store entity in tempstore with its UUID as tempstore key.
-    $this->tempStoreFactory->get('edit')->set($form_state['entity']->uuid(), $form_state['entity']);
+    $this->tempStoreFactory->get('quickedit')->set($form_state['entity']->uuid(), $form_state['entity']);
   }
 
   /**
diff --git a/core/modules/edit/lib/Drupal/edit/MetadataGenerator.php b/core/modules/quickedit/lib/Drupal/quickedit/MetadataGenerator.php
similarity index 87%
rename from core/modules/edit/lib/Drupal/edit/MetadataGenerator.php
rename to core/modules/quickedit/lib/Drupal/quickedit/MetadataGenerator.php
index 74d13f9..cc1443e 100644
--- a/core/modules/edit/lib/Drupal/edit/MetadataGenerator.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/MetadataGenerator.php
@@ -2,15 +2,15 @@
 
 /**
  * @file
- * Contains \Drupal\edit\MetadataGenerator.
+ * Contains \Drupal\quickedit\MetadataGenerator.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
-use Drupal\edit\Access\EditEntityFieldAccessCheckInterface;
+use Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface;
 use Drupal\field\FieldInstanceInterface;
 
 /**
@@ -21,14 +21,14 @@ class MetadataGenerator implements MetadataGeneratorInterface {
    /**
    * An object that checks if a user has access to edit a given entity field.
    *
-   * @var \Drupal\edit\Access\EditEntityFieldAccessCheckInterface
+   * @var \Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface
    */
   protected $accessChecker;
 
   /**
    * An object that determines which editor to attach to a given field.
    *
-   * @var \Drupal\edit\EditorSelectorInterface
+   * @var \Drupal\quickedit\EditorSelectorInterface
    */
   protected $editorSelector;
 
@@ -42,9 +42,9 @@ class MetadataGenerator implements MetadataGeneratorInterface {
   /**
    * Constructs a new MetadataGenerator.
    *
-   * @param \Drupal\edit\Access\EditEntityFieldAccessCheckInterface $access_checker
+   * @param \Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface $access_checker
    *   An object that checks if a user has access to edit a given field.
-   * @param \Drupal\edit\EditorSelectorInterface $editor_selector
+   * @param \Drupal\quickedit\EditorSelectorInterface $editor_selector
    *   An object that determines which editor to attach to a given field.
    * @param \Drupal\Component\Plugin\PluginManagerInterface
    *   The manager for editor plugins.
diff --git a/core/modules/edit/lib/Drupal/edit/MetadataGeneratorInterface.php b/core/modules/quickedit/lib/Drupal/quickedit/MetadataGeneratorInterface.php
similarity index 95%
rename from core/modules/edit/lib/Drupal/edit/MetadataGeneratorInterface.php
rename to core/modules/quickedit/lib/Drupal/quickedit/MetadataGeneratorInterface.php
index 3566cf8..628d61c 100644
--- a/core/modules/edit/lib/Drupal/edit/MetadataGeneratorInterface.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/MetadataGeneratorInterface.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\MetadataGeneratorInterface.
+ * Contains \Drupal\quickedit\MetadataGeneratorInterface.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
diff --git a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/DirectEditor.php b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/DirectEditor.php
similarity index 74%
rename from core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/DirectEditor.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/DirectEditor.php
index 6a8f16b..f42389a 100644
--- a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/DirectEditor.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/DirectEditor.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Plugin\InPlaceEditor\DirectEditor.
+ * Contains \Drupal\quickedit\Plugin\InPlaceEditor\DirectEditor.
  */
 
-namespace Drupal\edit\Plugin\InPlaceEditor;
+namespace Drupal\quickedit\Plugin\InPlaceEditor;
 
-use Drupal\edit\EditorBase;
-use Drupal\edit\Annotation\InPlaceEditor;
+use Drupal\quickedit\EditorBase;
+use Drupal\quickedit\Annotation\InPlaceEditor;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
 /**
@@ -41,12 +41,12 @@ function isCompatible(FieldDefinitionInterface $field_definition, array $items)
   }
 
   /**
-   * Implements \Drupal\edit\EditPluginInterface::getAttachments().
+   * Implements \Drupal\quickedit\EditPluginInterface::getAttachments().
    */
   public function getAttachments() {
     return array(
       'library' => array(
-        array('edit', 'edit.editorWidget.direct'),
+        array('quickedit', 'edit.editorWidget.direct'),
       ),
     );
   }
diff --git a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/FormEditor.php b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/FormEditor.php
similarity index 58%
rename from core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/FormEditor.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/FormEditor.php
index 4c71db2..74eea33 100644
--- a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditor/FormEditor.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditor/FormEditor.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Plugin\InPlaceEditor\FormEditor.
+ * Contains \Drupal\quickedit\Plugin\InPlaceEditor\FormEditor.
  */
 
-namespace Drupal\edit\Plugin\InPlaceEditor;
+namespace Drupal\quickedit\Plugin\InPlaceEditor;
 
-use Drupal\edit\EditorBase;
-use Drupal\edit\Annotation\InPlaceEditor;
+use Drupal\quickedit\EditorBase;
+use Drupal\quickedit\Annotation\InPlaceEditor;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
 /**
@@ -28,12 +28,12 @@ function isCompatible(FieldDefinitionInterface $field_definition, array $items)
   }
 
   /**
-   * Implements \Drupal\edit\EditPluginInterface::getAttachments().
+   * Implements \Drupal\quickedit\EditPluginInterface::getAttachments().
    */
   public function getAttachments() {
     return array(
       'library' => array(
-        array('edit', 'edit.editorWidget.form'),
+        array('quickedit', 'edit.editorWidget.form'),
       ),
     );
   }
diff --git a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditorManager.php b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditorManager.php
similarity index 67%
rename from core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditorManager.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditorManager.php
index f4c544b..c448196 100644
--- a/core/modules/edit/lib/Drupal/edit/Plugin/InPlaceEditorManager.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Plugin/InPlaceEditorManager.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Plugin\InPlaceEditorManager.
+ * Contains \Drupal\quickedit\Plugin\InPlaceEditorManager.
  */
 
-namespace Drupal\edit\Plugin;
+namespace Drupal\quickedit\Plugin;
 
 use Drupal\Component\Plugin\PluginManagerBase;
 use Drupal\Component\Plugin\Discovery\ProcessDecorator;
@@ -29,10 +29,10 @@ class InPlaceEditorManager extends PluginManagerBase {
    *   keyed by the corresponding namespace to look for plugin implementations,
    */
   public function __construct(\Traversable $namespaces) {
-    $annotation_namespaces = array('Drupal\edit\Annotation' => $namespaces['Drupal\edit']);
-    $this->discovery = new AnnotatedClassDiscovery('InPlaceEditor', $namespaces, $annotation_namespaces, 'Drupal\edit\Annotation\InPlaceEditor');
-    $this->discovery = new AlterDecorator($this->discovery, 'edit_editor');
-    $this->discovery = new CacheDecorator($this->discovery, 'edit:editor');
+    $annotation_namespaces = array('Drupal\quickedit\Annotation' => $namespaces['Drupal\quickedit']);
+    $this->discovery = new AnnotatedClassDiscovery('InPlaceEditor', $namespaces, $annotation_namespaces, 'Drupal\quickedit\Annotation\InPlaceEditor');
+    $this->discovery = new AlterDecorator($this->discovery, 'quickedit_editor');
+    $this->discovery = new CacheDecorator($this->discovery, 'quickedit:editor');
     $this->factory = new DefaultFactory($this->discovery);
   }
 
diff --git a/core/modules/edit/lib/Drupal/edit/Tests/EditTestBase.php b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditTestBase.php
similarity index 94%
rename from core/modules/edit/lib/Drupal/edit/Tests/EditTestBase.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Tests/EditTestBase.php
index 649f033..01d47f0 100644
--- a/core/modules/edit/lib/Drupal/edit/Tests/EditTestBase.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditTestBase.php
@@ -2,15 +2,15 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Tests\EditTestBase.
+ * Contains \Drupal\quickedit\Tests\EditTestBase.
  */
 
-namespace Drupal\edit\Tests;
+namespace Drupal\quickedit\Tests;
 
 use Drupal\simpletest\DrupalUnitTestBase;
 
 /**
- * Parent class for Edit tests.
+ * Parent class for Quick Edit tests.
  */
 class EditTestBase extends DrupalUnitTestBase {
 
@@ -19,7 +19,7 @@ class EditTestBase extends DrupalUnitTestBase {
    *
    * @var array
    */
-  public static $modules = array('system', 'entity', 'entity_test', 'field', 'field_sql_storage', 'field_test', 'number', 'text', 'edit');
+  public static $modules = array('system', 'entity', 'entity_test', 'field', 'field_sql_storage', 'field_test', 'number', 'text', 'quickedit');
   /**
    * Sets the default field storage backend for fields created during tests.
    */
diff --git a/core/modules/edit/lib/Drupal/edit/Tests/MetadataGeneratorTest.php b/core/modules/quickedit/lib/Drupal/quickedit/Tests/MetadataGeneratorTest.php
similarity index 92%
rename from core/modules/edit/lib/Drupal/edit/Tests/MetadataGeneratorTest.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Tests/MetadataGeneratorTest.php
index a930988..eaef9b7 100644
--- a/core/modules/edit/lib/Drupal/edit/Tests/MetadataGeneratorTest.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Tests/MetadataGeneratorTest.php
@@ -2,15 +2,15 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Tests\MetadataGeneratorTest.
+ * Contains \Drupal\quickedit\Tests\MetadataGeneratorTest.
  */
 
-namespace Drupal\edit\Tests;
+namespace Drupal\quickedit\Tests;
 
 use Drupal\Core\Language\Language;
-use Drupal\edit\EditorSelector;
-use Drupal\edit\MetadataGenerator;
-use Drupal\edit\Plugin\InPlaceEditorManager;
+use Drupal\quickedit\EditorSelector;
+use Drupal\quickedit\MetadataGenerator;
+use Drupal\quickedit\Plugin\InPlaceEditorManager;
 use Drupal\edit_test\MockEditEntityFieldAccessCheck;
 
 /**
@@ -28,21 +28,21 @@ class MetadataGeneratorTest extends EditTestBase {
   /**
    * The metadata generator object to be tested.
    *
-   * @var \Drupal\edit\MetadataGeneratorInterface.php
+   * @var \Drupal\quickedit\MetadataGeneratorInterface.php
    */
   protected $metadataGenerator;
 
   /**
    * The editor selector object to be used by the metadata generator object.
    *
-   * @var \Drupal\edit\EditorSelectorInterface
+   * @var \Drupal\quickedit\EditorSelectorInterface
    */
   protected $editorSelector;
 
   /**
    * The access checker object to be used by the metadata generator object.
    *
-   * @var \Drupal\edit\Access\EditEntityFieldAccessCheckInterface
+   * @var \Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface
    */
   protected $accessChecker;
 
@@ -50,14 +50,14 @@ public static function getInfo() {
     return array(
       'name' => 'In-place field editing metadata',
       'description' => 'Tests in-place field editing metadata generation.',
-      'group' => 'Edit',
+      'group' => 'Quick Edit',
     );
   }
 
   function setUp() {
     parent::setUp();
 
-    $this->editorManager = $this->container->get('plugin.manager.edit.editor');
+    $this->editorManager = $this->container->get('plugin.manager.quickedit.editor');
     $this->accessChecker = new MockEditEntityFieldAccessCheck();
     $this->editorSelector = new EditorSelector($this->editorManager);
     $this->metadataGenerator = new MetadataGenerator($this->accessChecker, $this->editorSelector, $this->editorManager);
diff --git a/core/modules/edit/edit.api.php b/core/modules/quickedit/quickedit.api.php
similarity index 64%
rename from core/modules/edit/edit.api.php
rename to core/modules/quickedit/quickedit.api.php
index 341220b..e199701 100644
--- a/core/modules/edit/edit.api.php
+++ b/core/modules/quickedit/quickedit.api.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Hooks provided by the Edit module.
+ * Hooks provided by the Quick Edit module.
  */
 
 /**
@@ -20,12 +20,12 @@
  *   An array of informations on existing in-place editors, as collected by the
  *   annotation discovery mechanism.
  *
- * @see \Drupal\edit\Annotation\InPlaceEditor
- * @see \Drupal\edit\Plugin\EditorManager
+ * @see \Drupal\quickedit\Annotation\InPlaceEditor
+ * @see \Drupal\quickedit\Plugin\EditorManager
  */
-function hook_edit_editor_alter(&$editors) {
+function hook_quickedit_editor_alter(&$editors) {
   // Cleanly override editor.module's in-place editor plugin.
-  $editors['editor']['class'] = 'Drupal\advanced_editor\Plugin\edit\editor\AdvancedEditor';
+  $editors['editor']['class'] = 'Drupal\advanced_editor\Plugin\quickedit\editor\AdvancedEditor';
 }
 
 /**
diff --git a/core/modules/edit/edit.info.yml b/core/modules/quickedit/quickedit.info.yml
similarity index 88%
rename from core/modules/edit/edit.info.yml
rename to core/modules/quickedit/quickedit.info.yml
index 4f07cdf..630f2fc 100644
--- a/core/modules/edit/edit.info.yml
+++ b/core/modules/quickedit/quickedit.info.yml
@@ -1,4 +1,4 @@
-name: Edit
+name: Quick Edit
 type: module
 description: 'In-place content editing.'
 package: Core
diff --git a/core/modules/edit/edit.module b/core/modules/quickedit/quickedit.module
similarity index 82%
rename from core/modules/edit/edit.module
rename to core/modules/quickedit/quickedit.module
index a7fbb5d..f750639 100644
--- a/core/modules/edit/edit.module
+++ b/core/modules/quickedit/quickedit.module
@@ -4,15 +4,15 @@
  * @file
  * Provides in-place content editing functionality for fields.
  *
- * The Edit module makes content editable in-place. Rather than having to visit
- * a separate page to edit content, it may be edited in-place.
+ * The Quick Edit module makes content editable in-place. Rather than having
+ * to visit a separate page to edit content, it may be edited in-place.
  *
  * Technically, this module adds classes and data- attributes to fields and
  * entities, enabling them for in-place editing.
  */
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\edit\Form\EditFieldForm;
+use Drupal\quickedit\Form\EditFieldForm;
 use Drupal\Component\Utility\NestedArray;
 use Drupal\entity\Plugin\Core\Entity\EntityDisplay;
 use Drupal\user\TempStoreFactory;
@@ -20,7 +20,7 @@
 /**
  * Implements hook_menu().
  */
-function edit_menu() {
+function quickedit_menu() {
   // @todo Remove these menu items in http://drupal.org/node/1954892 when theme
   //   callbacks are replaced with something else.
   $items['edit/metadata'] = array(
@@ -38,7 +38,7 @@ function edit_menu() {
 /**
  * Implements hook_permission().
  */
-function edit_permission() {
+function quickedit_permission() {
   return array(
     'access in-place editing' => array(
       'title' => t('Access in-place editing'),
@@ -52,7 +52,7 @@ function edit_permission() {
  * Adds the edit library to the page for any user who has the 'access in-place
  * editing' permission.
  */
-function edit_page_build(&$page) {
+function quickedit_page_build(&$page) {
   if (!user_access('access in-place editing')) {
     return;
   }
@@ -64,19 +64,19 @@ function edit_page_build(&$page) {
       'context' => 'body',
     )),
   );
-  $page['#attached']['library'][] = array('edit', 'edit');
+  $page['#attached']['library'][] = array('quickedit', 'edit');
 }
 
 /**
  * Implements hook_library_info().
  */
-function edit_library_info() {
-  $path = drupal_get_path('module', 'edit');
+function quickedit_library_info() {
+  $path = drupal_get_path('module', 'quickedit');
   $options = array(
     'scope' => 'footer',
   );
   $libraries['edit'] = array(
-    'title' => 'Edit: in-place editing',
+    'title' => 'Quick Edit: in-place editing',
     'version' => VERSION,
     'js' => array(
       // Core.
@@ -124,7 +124,7 @@ function edit_library_info() {
       $path . '/js/editors/formEditor.js' => $options,
     ),
     'dependencies' => array(
-      array('edit', 'edit'),
+      array('quickedit', 'edit'),
     ),
   );
   $libraries['edit.editorWidget.direct'] = array(
@@ -134,7 +134,7 @@ function edit_library_info() {
       $path . '/js/editors/directEditor.js' => $options,
     ),
     'dependencies' => array(
-      array('edit', 'edit'),
+      array('quickedit', 'edit'),
     ),
   );
 
@@ -144,12 +144,12 @@ function edit_library_info() {
 /**
  * Implements hook_field_formatter_info_alter().
  *
- * Edit extends the @FieldFormatter annotation with the following keys:
+ * Quick Edit extends the @FieldFormatter annotation with the following keys:
  * - edit: currently only contains one subkey 'editor' which indicates which
  *   in-place editor should be used. Possible values are 'form', 'direct' or
  *   'disabled'.
  */
-function edit_field_formatter_info_alter(&$info) {
+function quickedit_field_formatter_info_alter(&$info) {
   foreach ($info as $key => $settings) {
     // Set in-place editor to form if none is supplied.
     if (empty($settings['edit'])) {
@@ -161,7 +161,7 @@ function edit_field_formatter_info_alter(&$info) {
 /**
  * Implements hook_preprocess_HOOK() for field.tpl.php.
  */
-function edit_preprocess_field(&$variables) {
+function quickedit_preprocess_field(&$variables) {
   $element = $variables['element'];
   $entity = $element['#object'];
   $variables['attributes']['data-edit-id'] = $entity->entityType() . '/' . $entity->id() . '/' . $element['#field_name'] . '/' . $element['#language'] . '/' . $element['#view_mode'];
@@ -170,7 +170,7 @@ function edit_preprocess_field(&$variables) {
 /**
  * Implements hook_entity_view_alter().
  */
-function edit_entity_view_alter(&$build, EntityInterface $entity, EntityDisplay $display) {
+function quickedit_entity_view_alter(&$build, EntityInterface $entity, EntityDisplay $display) {
   $build['#attributes']['data-edit-entity'] = $entity->entityType() . '/' . $entity->id();
 }
 
@@ -179,7 +179,7 @@ function edit_entity_view_alter(&$build, EntityInterface $entity, EntityDisplay
  *
  * @ingroup forms
  */
-function edit_field_form(array $form, array &$form_state, EntityInterface $entity, $field_name, TempStoreFactory $temp_store_factory) {
+function quickedit_field_form(array $form, array &$form_state, EntityInterface $entity, $field_name, TempStoreFactory $temp_store_factory) {
   $form_handler = new EditFieldForm();
   return $form_handler->build($form, $form_state, $entity, $field_name, $temp_store_factory);
 }
diff --git a/core/modules/edit/edit.routing.yml b/core/modules/quickedit/quickedit.routing.yml
similarity index 70%
rename from core/modules/edit/edit.routing.yml
rename to core/modules/quickedit/quickedit.routing.yml
index b709d0a..1daac9e 100644
--- a/core/modules/edit/edit.routing.yml
+++ b/core/modules/quickedit/quickedit.routing.yml
@@ -1,21 +1,21 @@
 edit_metadata:
   pattern: '/edit/metadata'
   defaults:
-    _controller: '\Drupal\edit\EditController::metadata'
+    _controller: '\Drupal\quickedit\EditController::metadata'
   requirements:
     _permission: 'access in-place editing'
 
 edit_attachments:
   pattern: '/edit/attachments'
   defaults:
-    _controller: '\Drupal\edit\EditController::attachments'
+    _controller: '\Drupal\quickedit\EditController::attachments'
   requirements:
     _permission: 'access in-place editing'
 
 edit_field_form:
   pattern: '/edit/form/{entity_type}/{entity}/{field_name}/{langcode}/{view_mode_id}'
   defaults:
-    _controller: '\Drupal\edit\EditController::fieldForm'
+    _controller: '\Drupal\quickedit\EditController::fieldForm'
   requirements:
     _permission: 'access in-place editing'
     _access_edit_entity_field: 'TRUE'
@@ -24,7 +24,7 @@ edit_field_form:
 edit_entity_save:
   pattern: '/edit/entity/{entity_type}/{entity}'
   defaults:
-    _controller: '\Drupal\edit\EditController::entitySave'
+    _controller: '\Drupal\quickedit\EditController::entitySave'
   requirements:
     _permission: 'access in-place editing'
     _access_edit_entity: 'TRUE'
diff --git a/core/modules/quickedit/quickedit.services.yml b/core/modules/quickedit/quickedit.services.yml
new file mode 100644
index 0000000..5edd165
--- /dev/null
+++ b/core/modules/quickedit/quickedit.services.yml
@@ -0,0 +1,18 @@
+services:
+  plugin.manager.quickedit.editor:
+    class: Drupal\quickedit\Plugin\InPlaceEditorManager
+    arguments: ['@container.namespaces']
+  access_check.quickedit.entity_field:
+    class: Drupal\quickedit\Access\EditEntityFieldAccessCheck
+    tags:
+      - { name: access_check }
+  access_check.quickedit.entity:
+    class: Drupal\quickedit\Access\EditEntityAccessCheck
+    tags:
+      - { name: access_check }
+  quickedit.editor.selector:
+    class: Drupal\quickedit\EditorSelector
+    arguments: ['@plugin.manager.quickedit.editor']
+  quickedit.metadata.generator:
+    class: Drupal\quickedit\MetadataGenerator
+    arguments: ['@access_check.quickedit.entity_field', '@quickedit.editor.selector', '@plugin.manager.quickedit.editor']
diff --git a/core/modules/edit/tests/modules/edit_test.info.yml b/core/modules/quickedit/tests/modules/edit_test.info.yml
similarity index 100%
rename from core/modules/edit/tests/modules/edit_test.info.yml
rename to core/modules/quickedit/tests/modules/edit_test.info.yml
diff --git a/core/modules/edit/tests/modules/edit_test.module b/core/modules/quickedit/tests/modules/edit_test.module
similarity index 100%
rename from core/modules/edit/tests/modules/edit_test.module
rename to core/modules/quickedit/tests/modules/edit_test.module
diff --git a/core/modules/edit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php b/core/modules/quickedit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php
similarity index 89%
rename from core/modules/edit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php
rename to core/modules/quickedit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php
index 6dbaaa1..9e88e48 100644
--- a/core/modules/edit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php
+++ b/core/modules/quickedit/tests/modules/lib/Drupal/edit_test/MockEditEntityFieldAccessCheck.php
@@ -11,7 +11,7 @@
 namespace Drupal\edit_test;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\edit\Access\EditEntityFieldAccessCheckInterface;
+use Drupal\quickedit\Access\EditEntityFieldAccessCheckInterface;
 
 /**
  * Access check for editing entity fields.
diff --git a/core/modules/edit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php b/core/modules/quickedit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php
similarity index 90%
rename from core/modules/edit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php
rename to core/modules/quickedit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php
index 61be894..1b89af1 100644
--- a/core/modules/edit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php
+++ b/core/modules/quickedit/tests/modules/lib/Drupal/edit_test/Plugin/InPlaceEditor/WysiwygEditor.php
@@ -7,8 +7,8 @@
 
 namespace Drupal\edit_test\Plugin\InPlaceEditor;
 
-use Drupal\edit\EditorBase;
-use Drupal\edit\Annotation\InPlaceEditor;
+use Drupal\quickedit\EditorBase;
+use Drupal\quickedit\Annotation\InPlaceEditor;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
 
 /**
@@ -51,7 +51,7 @@ function getMetadata(FieldDefinitionInterface $field_definition, array $items) {
   }
 
   /**
-   * Implements \Drupal\edit\EditPluginInterface::getAttachments().
+   * Implements \Drupal\quickedit\EditPluginInterface::getAttachments().
    */
   public function getAttachments() {
     return array(
diff --git a/core/profiles/standard/standard.info.yml b/core/profiles/standard/standard.info.yml
index 2dfadbb..e8da035 100644
--- a/core/profiles/standard/standard.info.yml
+++ b/core/profiles/standard/standard.info.yml
@@ -16,7 +16,6 @@ dependencies:
   - contact
   - datetime
   - custom_block
-  - edit
   - editor
   - help
   - image
@@ -24,6 +23,7 @@ dependencies:
   - number
   - options
   - path
+  - quickedit
   - taxonomy
   - dblog
   - search

diff --git a/core/modules/edit/lib/Drupal/edit/EditPluginInterface.php b/core/modules/quickedit/lib/Drupal/quickedit/EditPluginInterface.php
similarity index 90%
rename from core/modules/edit/lib/Drupal/edit/EditPluginInterface.php
rename to core/modules/quickedit/lib/Drupal/quickedit/EditPluginInterface.php
index 1dcc642..d779687 100644
--- a/core/modules/edit/lib/Drupal/edit/EditPluginInterface.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/EditPluginInterface.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\edit\EditPluginInterface.
+ * Contains \Drupal\quickedit\EditPluginInterface.
  */
 
-namespace Drupal\edit;
+namespace Drupal\quickedit;
 
 use Drupal\Component\Plugin\PluginInspectionInterface;
 use Drupal\Core\Entity\Field\FieldDefinitionInterface;
@@ -34,7 +34,7 @@ public function isCompatible(FieldDefinitionInterface $field_definition, array $
   /**
    * Generates metadata that is needed specifically for this editor.
    *
    * Will only be called by \Drupal\edit\MetadataGeneratorInterface::generate()
    * when the passed in field instance & item values will use this editor.
    *
    * @param \Drupal\Core\Entity\Field\FieldDefinitionInterface $field_definition
@@ -34,7 +34,7 @@ public function isCompatible(FieldDefinitionInterface $field_definition, array $
    * Generates metadata that is needed specifically for this editor.
    *
-   * Will only be called by \Drupal\edit\MetadataGeneratorInterface::generate()
+   * Will only be called by \Drupal\quickedit\MetadataGeneratorInterface::generate()
    * when the passed in field instance & item values will use this editor.
    *
diff --git a/core/modules/edit/lib/Drupal/edit/Tests/EditLoadingTest.php b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditLoadingTest.php
similarity index 91%
rename from core/modules/edit/lib/Drupal/edit/Tests/EditLoadingTest.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Tests/EditLoadingTest.php
index 4807d4e..b0e911f 100644
--- a/core/modules/edit/lib/Drupal/edit/Tests/EditLoadingTest.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditLoadingTest.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Tests\EditLoadingTest.
+ * Contains \Drupal\quickedit\Tests\EditLoadingTest.
  */
 
-namespace Drupal\edit\Tests;
+namespace Drupal\quickedit\Tests;
 
 use Drupal\simpletest\WebTestBase;
-use Drupal\edit\Ajax\MetadataCommand;
+use Drupal\quickedit\Ajax\MetadataCommand;
 use Drupal\Core\Ajax\AppendCommand;
 use Drupal\Component\Utility\Unicode;
 
 /**
  * Tests loading of Edit and lazy-loading of in-place editors.
  */
 class EditLoadingTest extends WebTestBase {
 
@@ -22,13 +22,13 @@ class EditLoadingTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('contextual', 'edit', 'filter', 'node');
+  public static $modules = array('contextual', 'quickedit', 'filter', 'node');
 
   public static function getInfo() {
     return array(
       'name' => 'In-place editing loading',
       'description' => 'Tests loading of in-place editing functionality and lazy loading of its in-place editors.',
-      'group' => 'Edit',
+      'group' => 'Quick Edit',
     );
   }
 
@@ -69,7 +69,7 @@ function setUp() {
   }
 
   /**
    * Test the loading of Edit when a user doesn't have access to it.
    */
   function testUserWithoutPermission() {
     $this->drupalLogin($this->author_user);
@@ -77,9 +77,9 @@ function testUserWithoutPermission() {
 
     // Settings, library and in-place editors.
     $settings = $this->drupalGetSettings();
-    $this->assertFalse(isset($settings['edit']), 'Edit settings do not exist.');
-    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/edit/js/edit.js']), 'Edit library not loaded.');
-    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/edit/js/createjs/editingWidgets/formwidget.js']), "'form' in-place editor not loaded.");
+    $this->assertFalse(isset($settings['edit']), 'Quick Edit settings do not exist.');
+    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/quickedit/js/edit.js']), 'Quick Edit library not loaded.');
+    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/quickedit/js/createjs/editingWidgets/formwidget.js']), "'form' in-place editor not loaded.");
 
     // HTML annotation must always exist (to not break the render cache).
     $this->assertRaw('data-edit-entity="node/1"');
@@ -92,7 +92,7 @@ function testUserWithoutPermission() {
   }
 
   /**
    * Tests the loading of Edit when a user does have access to it.
    *
    * Also ensures lazy loading of in-place editors works.
    */
@@ -102,9 +102,9 @@ function testUserWithPermission() {
 
     // Settings, library and in-place editors.
     $settings = $this->drupalGetSettings();
-    $this->assertTrue(isset($settings['edit']), 'Edit settings exist.');
-    $this->assertTrue(isset($settings['ajaxPageState']['js']['core/modules/edit/js/edit.js']), 'Edit library loaded.');
-    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/edit/js/createjs/editingWidgets/formwidget.js']), "'form' in-place editor not loaded.");
+    $this->assertTrue(isset($settings['edit']), 'Quick Edit settings exist.');
+    $this->assertTrue(isset($settings['ajaxPageState']['js']['core/modules/quickedit/js/edit.js']), 'Quick Edit library loaded.');
+    $this->assertFalse(isset($settings['ajaxPageState']['js']['core/modules/quickedit/js/createjs/editingWidgets/formwidget.js']), "'form' in-place editor not loaded.");
 
     // HTML annotation must always exist (to not break the render cache).
     $this->assertRaw('data-edit-entity="node/1"');
@@ -137,7 +137,7 @@ function testUserWithPermission() {
     $this->assertIdentical('settings', $ajax_commands[0]['command'], 'The first AJAX command is a settings command.');
     // Second command: insert libraries into DOM.
     $this->assertIdentical('insert', $ajax_commands[1]['command'], 'The second AJAX command is an append command.');
-    $command = new AppendCommand('body', '<script src="' . file_create_url('core/modules/edit/js/editors/formEditor.js') . '?v=' . VERSION . '"></script>' . "\n");
+    $command = new AppendCommand('body', '<script src="' . file_create_url('core/modules/quickedit/js/editors/formEditor.js') . '?v=' . VERSION . '"></script>' . "\n");
     $this->assertIdentical($command->render(), $ajax_commands[1], 'The append command contains the expected data.');
 
     // Retrieving the form for this field should result in a 200 response,
@@ -194,8 +194,10 @@ function testUserWithPermission() {
   }
 
   /**
    * Retrieve Edit metadata from the server. May also result in additional
    * JavaScript settings and CSS/JS being loaded.
    *
    * @param array $ids
    *   An array of edit ids.
@@ -272,7 +274,7 @@ protected function retrieveAttachments($editors) {
    * Submit field form data to the server.
    *
    * @param string $field_id
    *   An Edit field ID.
    * @param array $post
    *   An array of post data to send.
    *
@@ -306,7 +308,7 @@ protected function submitFieldForm($field_id, $post) {
    * JavaScript settings and CSS/JS being loaded.
    *
    * @param string $field_id
    *   An Edit field ID.
    *
    * @return string
    *   The response body.
@@ -2,18 +2,18 @@
 
 /**
- * Tests loading of Edit and lazy-loading of in-place editors.
+ * Tests loading of Quick Edit and lazy-loading of in-place editors.
  */
 class EditLoadingTest extends WebTestBase {
@@ -69,7 +69,7 @@ function setUp() {
 
   /**
-   * Test the loading of Edit when a user doesn't have access to it.
+   * Test the loading of Quick Edit when a user doesn't have access to it.
    */
   function testUserWithoutPermission() {
@@ -92,7 +92,7 @@ function testUserWithoutPermission() {
 
   /**
-   * Tests the loading of Edit when a user does have access to it.
+   * Tests the loading of Quick Edit when a user does have access to it.
    *
    * Also ensures lazy loading of in-place editors works.
@@ -194,8 +194,10 @@ function testUserWithPermission() {
 
   /**
-   * Retrieve Edit metadata from the server. May also result in additional
-   * JavaScript settings and CSS/JS being loaded.
+   * Retrieve Quick Edit metadata from the server.
+   *
+   * This may also result in additional JavaScript settings and CSS/JS being
+   * loaded.
    *
    * @param array $ids
@@ -272,7 +274,7 @@ protected function retrieveAttachments($editors) {
    *
    * @param string $field_id
-   *   An Edit field ID.
+   *   A Quick Edit field ID.
    * @param array $post
    *   An array of post data to send.
@@ -306,7 +308,7 @@ protected function submitFieldForm($field_id, $post) {
    *
    * @param string $field_id
-   *   An Edit field ID.
+   *   A Quick Edit field ID.
    *
    * @return string
diff --git a/core/modules/edit/lib/Drupal/edit/Tests/EditorSelectionTest.php b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditorSelectionTest.php
similarity index 94%
rename from core/modules/edit/lib/Drupal/edit/Tests/EditorSelectionTest.php
rename to core/modules/quickedit/lib/Drupal/quickedit/Tests/EditorSelectionTest.php
index c1982c5..f7b399c 100644
--- a/core/modules/edit/lib/Drupal/edit/Tests/EditorSelectionTest.php
+++ b/core/modules/quickedit/lib/Drupal/quickedit/Tests/EditorSelectionTest.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\edit\Tests\EditorSelectionTest.
+ * Contains \Drupal\quickedit\Tests\EditorSelectionTest.
  */
 
-namespace Drupal\edit\Tests;
+namespace Drupal\quickedit\Tests;
 
-use Drupal\edit\Plugin\InPlaceEditorManager;
-use Drupal\edit\EditorSelector;
+use Drupal\quickedit\Plugin\InPlaceEditorManager;
+use Drupal\quickedit\EditorSelector;
 
 /**
  * Test in-place field editor selection.
@@ -25,7 +25,7 @@ class EditorSelectionTest extends EditTestBase {
   /**
    * The editor selector object to be tested.
    *
-   * @var \Drupal\edit\EditorSelectorInterface
+   * @var \Drupal\quickedit\EditorSelectorInterface
    */
   protected $editorSelector;
 
@@ -33,20 +33,19 @@ public static function getInfo() {
     return array(
       'name' => 'In-place field editor selection',
       'description' => 'Tests in-place field editor selection.',
-      'group' => 'Edit',
+      'group' => 'Quick Edit',
     );
   }
 
   function setUp() {
     parent::setUp();
 
-    $this->editorManager = $this->container->get('plugin.manager.edit.editor');
+    $this->editorManager = $this->container->get('plugin.manager.quickedit.editor');
     $this->editorSelector = new EditorSelector($this->editorManager);
   }
 
   /**
    * Retrieves the FieldInstance object for the given field and returns the
    * editor that Edit selects.
    */
   protected function getSelectedEditor($items, $field_name, $view_mode = 'default') {
     $options = entity_get_display('entity_test', 'entity_test', $view_mode)->getComponent($field_name);
@@ -33,20 +33,19 @@ public static function getInfo() {
 
   /**
-   * Retrieves the FieldInstance object for the given field and returns the
-   * editor that Edit selects.
+   * Returns the editor that Quick Edit selects for a given field.
    */
   protected function getSelectedEditor($items, $field_name, $view_mode = 'default') {